/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.command;

import org.fortiss.tooling.base.dnd.ConnectionDragContext;
import org.fortiss.tooling.base.model.base.ConnectionSegmentBase;
import org.fortiss.tooling.base.ui.editpart.policy.DirectConnectionAndReconnectionEditPolicy;
import org.fortiss.tooling.kernel.service.IConnectionCompositorService;

/**
 * This command is used by {@link DirectConnectionAndReconnectionEditPolicy} to
 * communicate with {@link IConnectionCompositorService} for altering a
 * connection's source or target model element.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 4EE31C09FB94713D877AE61E125129A1
 */
public class ReconnectCommand extends ConnectCommand {

	/** Stores connection to be altered. */
	private final ConnectionSegmentBase connection;

	/** Constructor. */
	public ReconnectCommand(ConnectionDragContext context, ConnectionSegmentBase connection) {
		super(context);
		this.connection = connection;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canExecute() {
		if(context == null || context.getSource() == null || context.getTarget() == null) {
			return false;
		}
		return IConnectionCompositorService.getInstance().canReconnect(connection, context.getSource(),
				context.getTarget(), context);
	}

	/** {@inheritDoc} */
	@Override
	public void execute() {
		IConnectionCompositorService.getInstance().reconnect(connection, context.getSource(),
				context.getTarget(), context);
	}
}
