/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.figure;

import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.Graphics;
import org.eclipse.draw2d.Shape;
import org.eclipse.draw2d.geometry.Insets;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.swt.SWT;

/**
 * This shape consists of a rounded rectangle that is surrounded by transparent
 * insets. The rounded rectangle is filled with {@link #getBackgroundColor()}. A
 * light top-down gradient from white to the background color is painted over
 * the background color to achieve a 3 dimensional reflection effect.
 * <p>
 * Anti-aliasing is enabled for smooth corners of the rounded rectangle.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 5D74EBE94DE01FC23D3A1366FA0A39BA
 */
public class PrettyRoundedRectangle extends Shape {

	/** The radius to use for the rounded corners of this shape. */
	protected final int cornerRadius;

	/** The transparent insets surrounding this shape. */
	protected final Insets insets;

	/** Constructor. */
	public PrettyRoundedRectangle(int cornerRadius, Insets insets) {
		this.cornerRadius = cornerRadius;
		this.insets = insets;
	}

	/** {@inheritDoc} */
	@Override
	protected void fillShape(Graphics gfx) {
		gfx.pushState();
		// Traditional style is default.
		gfx.fillRoundRectangle(getCroppedBounds(), cornerRadius, cornerRadius);
		gfx.setForegroundColor(ColorConstants.white);
		gfx.setAlpha(200);
		gfx.fillGradient(getCroppedBounds().resize(0, -cornerRadius), true);
		gfx.popState();
	}

	/** Returns a copy of the bounds cropped by the insets. */
	protected Rectangle getCroppedBounds() {
		return bounds.getShrinked(insets);
	}

	/**
	 * {@inheritDoc}
	 * <p>
	 * Additionally enables anti-aliasing.
	 */
	@Override
	protected void outlineShape(Graphics gfx) {
		gfx.pushState();
		gfx.setAntialias(SWT.ON);
		gfx.drawRoundRectangle(getCroppedBounds().resize(-1, -1), cornerRadius, cornerRadius);
		gfx.popState();
	}
}
