/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.policy;

import org.eclipse.draw2d.PositionConstants;
import org.eclipse.gef.Request;
import org.eclipse.gef.editpolicies.ResizableEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.editpart.ElementEditPartBase;
import org.fortiss.tooling.base.ui.layout.IDiagramLayoutConfiguration;

/**
 * EditPolicy for element resizing and movement. It delegates the source
 * feedback alteration to the {@link IDiagramLayoutConfiguration}.
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 41C820EF5786DD7A1FDF31BBD9DE8750
 */
public class ElementMoveAndSouthEastResizeEditPolicy extends ResizableEditPolicy {

	/** Constructor. */
	public ElementMoveAndSouthEastResizeEditPolicy() {
		// enable resizing on east, south-east and south handles.
		setResizeDirections(PositionConstants.SOUTH_EAST);
	}

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public void showSourceFeedback(Request request) {
		if(REQ_RESIZE.equals(request.getType())) {
			ElementEditPartBase<? extends ILayoutedModelElement> editPart =
					(ElementEditPartBase<? extends ILayoutedModelElement>)getHost();
			editPart.getLayoutConfiguration().alterElementMoveAndResizeFeedbackRequest(
					(ChangeBoundsRequest)request, editPart);
		}
		super.showSourceFeedback(request);
	}
}
