/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.policy;

import org.eclipse.gef.Request;
import org.eclipse.gef.editpolicies.NonResizableEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.ui.editpart.ElementEditPartBase;
import org.fortiss.tooling.base.ui.editpart.StickyConnectorEditPartBase;
import org.fortiss.tooling.base.ui.layout.IDiagramLayoutConfiguration;
import org.fortiss.tooling.kernel.model.INamedCommentedElement;

/**
 * EditPolicy for keeping a connector sticking to the border of it's parent
 * element. The concrete feedback position is determine by the {@link IDiagramLayoutConfiguration}.
 * <p>
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 533D26CC64B007DE3C861317A657CB7D
 */
public class StickyConnectorMoveEditPolicy<T extends ILayoutedModelElement & INamedCommentedElement>
		extends NonResizableEditPolicy {

	/** Stores the parent edit part of the sticky connector. */
	private final ElementEditPartBase<T> part;

	/** Constructor. */
	public StickyConnectorMoveEditPolicy(ElementEditPartBase<T> part) {
		this.part = part;
	}

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public void showSourceFeedback(Request request) {
		if(REQ_MOVE.equals(request.getType())) {
			part.getLayoutConfiguration().alterStickyConnectorMoveFeedbackRequest(
					(ChangeBoundsRequest)request,
					(StickyConnectorEditPartBase<? extends ILayoutedModelElement>)getHost(),
					getHostFigure());
		}
		super.showSourceFeedback(request);
	}
}
