/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.items;

import static java.util.Collections.unmodifiableSet;

import java.util.Collection;
import java.util.Map;

import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.extension.IConstraintVerifierUI;
import org.fortiss.tooling.kernel.ui.service.IConstraintVerificationUIService;

/**
 * {@link IIntrospectionDetailsItem} for {@link IConstraintVerificationUIService}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 084584C0687A698FDB75F67E9C2ADA9A
 */
public final class ConstraintVerificationUIServiceIntrospectionDetailsItem implements
		IIntrospectionDetailsItem {

	/** Read-only copy of the services handler list. */
	protected final Map<String, IConstraintVerifierUI> handlerMap;

	/** Constructor. */
	public ConstraintVerificationUIServiceIntrospectionDetailsItem(
			Map<String, IConstraintVerifierUI> handlerMap) {
		this.handlerMap = handlerMap;
	}

	/** Returns the first registration classes. */
	public Collection<String> getHandlerKeyClasses() {
		return unmodifiableSet(handlerMap.keySet());
	}

	/** Returns the handler list for the given registration class. */
	public IConstraintVerifierUI getHandler(String regClass) {
		return handlerMap.get(regClass);
	}
}
