/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import static org.conqat.lib.commons.collections.CollectionUtils.asUnmodifiable;

import java.util.LinkedList;
import java.util.List;

/**
 * A composite tutorial step, i.e., a step which encapsulates other tutorial steps.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating YELLOW Hash: 1A5492A3A9D8C0AEB6CA24B25811254F
 */
public class TutorialCompositeStep extends TutorialStepBase {
	/** The list of contained steps. */
	private final List<TutorialStepBase> steps = new LinkedList<TutorialStepBase>();

	// TODO(VA) Do we need absolutely a first step? Why isn't there a constructor to build an empty
	// step first?
	/** Constructor. */
	public TutorialCompositeStep(String title, String url, TutorialStepBase firstStep) {
		super(title, url);
		addStep(firstStep);
	}

	/** Constructor. */
	public TutorialCompositeStep(String title, TutorialStepBase firstStep) {
		this(title, "", firstStep);
	}

	/** Adds the given step to the end of the step list. */
	public final void addStep(TutorialStepBase step) {
		if(step == null) {
			throw new NullPointerException("TutorialStep element must not be null.");
		}
		steps.add(step);
		step.setParent(this);
	}

	/** Returns steps. */
	public final List<TutorialStepBase> getSteps() {
		return asUnmodifiable(steps);
	}
}
