/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service.listener;

import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;

/**
 * Listener interface notified by the persistency service whenever the list of
 * top-level elements changes (element added or removed) or the content of the
 * top-level element changed. The latter case usually occurs when the model is
 * saved to disk or a new revision is available remotely.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: CA9B2AE87CCED05A17C99E032BD98926
 */
public interface IPersistencyServiceListener {

	/**
	 * Notifies the listener that the given element just appeared in the
	 * persistency service.
	 */
	void topLevelElementAdded(ITopLevelElement element);

	/**
	 * Notifies the listener that the given element just disappeared in the
	 * persistency service.
	 */
	void topLevelElementRemoved(ITopLevelElement element);

	/**
	 * Notifies the listener that the underlying persistent model content has
	 * changed.
	 */
	void topLevelElementContentChanged(ITopLevelElement element);
}
